summaryrefslogtreecommitdiffstats
path: root/kttsd/plugins/freetts/freettsconf.h
diff options
context:
space:
mode:
Diffstat (limited to 'kttsd/plugins/freetts/freettsconf.h')
-rw-r--r--kttsd/plugins/freetts/freettsconf.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kttsd/plugins/freetts/freettsconf.h b/kttsd/plugins/freetts/freettsconf.h
index 9ab3ae8..b8e252e 100644
--- a/kttsd/plugins/freetts/freettsconf.h
+++ b/kttsd/plugins/freetts/freettsconf.h
@@ -18,7 +18,7 @@
#ifndef _FREETTSCONF_H_
#define _FREETTSCONF_H_
-#include <qstringlist.h>
+#include <tqstringlist.h>
#include <kdebug.h>
#include <kconfig.h>
@@ -36,7 +36,7 @@ class FreeTTSConf : public PlugInConf {
public:
/** Constructor */
- FreeTTSConf( QWidget* parent = 0, const char* name = 0, const QStringList &args = QStringList());
+ FreeTTSConf( TQWidget* parent = 0, const char* name = 0, const TQStringList &args = TQStringList());
/** Destructor */
~FreeTTSConf();
@@ -47,13 +47,13 @@ class FreeTTSConf : public PlugInConf {
the control center, to undo all of his changes and restore the currently
valid settings. NOTE that this is not called after the modules is loaded,
so you probably want to call this method in the constructor.*/
- void load(KConfig *config, const QString &configGroup);
+ void load(KConfig *config, const TQString &configGroup);
/** This function gets called when the user wants to save the settings in
the user interface, updating the config files or wherever the
configuration is stored. The method is called when the user clicks "Apply"
or "Ok". */
- void save(KConfig *config, const QString &configGroup);
+ void save(KConfig *config, const TQString &configGroup);
/** This function is called to set the settings in the module to sensible
default values. It gets called when hitting the "Default" button. The
@@ -65,7 +65,7 @@ class FreeTTSConf : public PlugInConf {
* This function informs the plugin of the desired language to be spoken
* by the plugin. The plugin should attempt to adapt itself to the
* specified language code, choosing sensible defaults if necessary.
* If the passed-in code is QString::null, no specific language has
* been chosen.
* @param lang The desired language code or Null if none.
*
@@ -77,22 +77,22 @@ class FreeTTSConf : public PlugInConf {
* not the given country, treat it as though the country
* code were not specified, i.e., adapt to the given language.
*/
- void setDesiredLanguage(const QString &lang);
+ void setDesiredLanguage(const TQString &lang);
/**
* Return fully-specified talker code for the configured plugin. This code
* uniquely identifies the configured instance of the plugin and distinquishes
* one instance from another. If the plugin has not been fully configured,
* i.e., cannot yet synthesize, return QString::null.
* @return Fully-specified talker code.
*/
- QString getTalkerCode();
+ TQString getTalkerCode();
/**
* Function searches the $PATH for a file. If it exists, it returns the full path
* to that file. If not, then it returns an empty QString.
* @param name The name of the file to search for.
* @returns The full path to the file or an empty QString.
*/
private slots:
@@ -105,7 +105,7 @@ class FreeTTSConf : public PlugInConf {
private:
/// Language code.
- QString m_languageCode;
+ TQString m_languageCode;
/// Configuration Widget.
FreeTTSConfWidget *m_widget;
@@ -114,7 +114,7 @@ class FreeTTSConf : public PlugInConf {
FreeTTSProc *m_freettsProc;
/// Synthesized wave file name.
- QString m_waveFile;
+ TQString m_waveFile;
/// Progress dialog.
KProgressDialog* m_progressDlg;
@@ -65,7 +65,7 @@ class FreeTTSConf : public PlugInConf {
* by the plugin. The plugin should attempt to adapt itself to the
* specified language code, choosing sensible defaults if necessary.
- * If the passed-in code is QString::null, no specific language has
+ * If the passed-in code is TQString::null, no specific language has
* been chosen.
* @param lang The desired language code or Null if none.
@@ -77,22 +77,22 @@ class FreeTTSConf : public PlugInConf {
* uniquely identifies the configured instance of the plugin and distinquishes
* one instance from another. If the plugin has not been fully configured,
- * i.e., cannot yet synthesize, return QString::null.
+ * i.e., cannot yet synthesize, return TQString::null.
* @return Fully-specified talker code.
*/
@@ -77,22 +77,22 @@ class FreeTTSConf : public PlugInConf {
/**
* Function searches the $PATH for a file. If it exists, it returns the full path
- * to that file. If not, then it returns an empty QString.
+ * to that file. If not, then it returns an empty TQString.
* @param name The name of the file to search for.
@@ -77,22 +77,22 @@ class FreeTTSConf : public PlugInConf {
* @param name The name of the file to search for.
- * @returns The full path to the file or an empty QString.
+ * @returns The full path to the file or an empty TQString.
*/
private slots: